﻿using System;
using System.Collections.Generic;
using System.Text;
using UnityEngine;
using System.Linq;
using System.IO;

public class BasicSpawner : Mod
{
    private List<Item_Base> items = new List<Item_Base>();
    public static BasicSpawner instance;

    private void Start()
    {
        instance = this;
        GenerateList();
        Debug.Log("BasicSpawner loaded!");
    }


    private void GenerateList()
    {
        items = ItemManager.GetAllItems();
    }

    public void SpawnItem(string[] args)
    {
        if (args.Length == 0)
        {
            Debug.Log("Please include an item name after eg \"spawn Paddle\"");
        }
        else
        {
            string itemName = args[0];
            int amount = 1;
            if (args.Length > 1)
            {
                string itemAmount = args[1];
                int result;
                if (int.TryParse(itemAmount, out result))
                {
                    amount = result;
                }
            }

            for (int i = 0; i < items.Count; i++)
            {
                if (items[i].UniqueName.ToLower() == itemName.ToLower())
                {
                    PlayerInventory pi = ComponentManager<PlayerInventory>.Value;
                    try
                    {
                        pi.AddItem(items[i].UniqueName, amount);
                        Debug.Log("Have given player " + amount + " " + items[i].UniqueName);
                    }
                    catch (Exception e)
                    {
                        Debug.LogError(e.ToString());
                    }
                    return;
                }
            }

            Debug.Log("Couldn't find the item called " + itemName);
        }

    }

    public void PrintItems()
    {
        string longString = "";
        foreach (Item_Base item in items)
        {
            longString += " | " + item.UniqueName;
        }

        Debug.Log(longString);
        Debug.Log("This is a long list, but it is recomended to export a generated list and view in it a text editor of your choice.\nWith the command \"exportItemList\"");
    }

    public void ExportList()
    {
        Directory.CreateDirectory(Directory.GetCurrentDirectory() + @"\mods\BasicSpawner");

        Debug.Log("Exporting list to " + Directory.GetCurrentDirectory() + @"\mods\BasicSpawner\itemList.txt");
        StreamWriter writer = new StreamWriter(Directory.GetCurrentDirectory() + @"\mods\BasicSpawner\itemList.txt");

        foreach (Item_Base item in items)
        {
            writer.WriteLine("UniqueName: " + item.UniqueName + " ID: " + item.UniqueIndex + " Display Name: " + item.name);
        }

        writer.Close();
        Debug.Log("Finished Exporting!");
    }
    public void OnModUnload()
    {
        Debug.Log("BasicSpawner has been unloaded!");
        Destroy(gameObject);
    }

    [ConsoleCommand(name: "spawn", docs: "Spawns the item")]
    public static void spawnCommand(string[] args)
    {
        instance.SpawnItem(args);
    }

    [ConsoleCommand(name: "itemListConsole", docs: "List all the items into the console")]
    public static void itemListConsoleCommand(string[] args)
    {
        instance.PrintItems();
    }

    [ConsoleCommand(name: "exportItemList", docs: "Exports the list of items to a .txt file")]
    public static void exportItemListCommand(string[] args)
    {
        instance.ExportList();
    }
}